@@ -337,8 +337,10 @@ class PGInterval:
         self.microseconds = microseconds
 
     def __repr__(self):
-        res = ["<PGInterval"]
-        for name, value in (
+        return f"<PGInterval {self}>"
+
+    def __str__(self):
+        pairs = (
             ("millennia", self.millennia),
             ("centuries", self.centuries),
             ("decades", self.decades),
@@ -350,60 +352,8 @@ class PGInterval:
             ("minutes", self.minutes),
             ("seconds", self.seconds),
             ("microseconds", self.microseconds),
-        ):
-            if value is not None:
-                res.append(str(value))
-                res.append(name)
-
-        return " ".join(res) + ">"
-
-    def __str__(self):
-        res = []
-        if self.millennia is not None:
-            res.append(str(self.millenia))
-            res.append("millenia")
-
-        if self.centuries is not None:
-            res.append(str(self.centuries))
-            res.append("centuries")
-
-        if self.decades is not None:
-            res.append(str(self.decades))
-            res.append("decades")
-
-        if self.years is not None:
-            res.append(str(self.years))
-            res.append("years")
-
-        if self.months is not None:
-            res.append(str(self.months))
-            res.append("months")
-
-        if self.weeks is not None:
-            res.append(str(self.weeks))
-            res.append("weeks")
-
-        if self.days is not None:
-            res.append(str(self.days))
-            res.append("days")
-
-        if self.hours is not None:
-            res.append(str(self.hours))
-            res.append("hours")
-
-        if self.minutes is not None:
-            res.append(str(self.minutes))
-            res.append("minutes")
-
-        if self.seconds is not None:
-            res.append(str(self.seconds))
-            res.append("seconds")
-
-        if self.microseconds is not None:
-            res.append(str(self.microseconds))
-            res.append("microseconds")
-
-        return " ".join(res)
+        )
+        return " ".join(f"{v} {n}" for n, v in pairs if v is not None)
 
     def normalize(self):
         months = 0
@@ -736,3 +686,50 @@ def make_param(py_types, value):
 
 def make_params(py_types, values):
     return tuple([make_param(py_types, v) for v in values])
+
+
+def identifier(sql):
+    if not isinstance(sql, str):
+        raise InterfaceError("identifier must be a str")
+
+    if len(sql) == 0:
+        raise InterfaceError("identifier must be > 0 characters in length")
+
+    quote = not sql[0].isalpha()
+
+    for c in sql[1:]:
+        if not (c.isalpha() or c.isdecimal() or c in "_$"):
+            if c == "\u0000":
+                raise InterfaceError(
+                    "identifier cannot contain the code zero character"
+                )
+            quote = True
+            break
+
+    if quote:
+        sql = sql.replace('"', '""')
+        return f'"{sql}"'
+    else:
+        return sql
+
+
+def literal(value):
+    if value is None:
+        return "NULL"
+    elif isinstance(value, bool):
+        return "TRUE" if value else "FALSE"
+    elif isinstance(value, (int, float, Decimal)):
+        return str(value)
+    elif isinstance(value, (bytes, bytearray)):
+        return f"X'{value.hex()}'"
+    elif isinstance(value, Date):
+        return f"'{date_out(value)}'"
+    elif isinstance(value, Time):
+        return f"'{time_out(value)}'"
+    elif isinstance(value, Datetime):
+        return f"'{datetime_out(value)}'"
+    elif isinstance(value, Timedelta):
+        return f"'{interval_out(value)}'"
+    else:
+        val = str(value).replace("'", "''")
+        return f"'{val}'"
